import React, { useMemo } from 'react';
import ReactDOM from 'react-dom';
import { useDidUpdateEffect } from '@devesharp/react-hooks';
import { IModalProps } from './Modal.interface';
import { ModalContainerStyle, ModalStyle } from './Modal.style';

export const Modal: React.FunctionComponent<IModalProps> & { Body: React.FunctionComponent<any> } = (props) => {
   const { children, show, onRequestClose = () => {}, onHide, ...rest } = props;

   useDidUpdateEffect(() => {
      if (!show) {
         if (onHide) onHide();
      }
   }, [show]);

   return ReactDOM.createPortal(
      <>
         {show && (
            <ModalContainerStyle {...rest}>
               <div className="modal-container">
                  <div
                     className="bg-background"
                     data-testid="bg-modal"
                     onClick={() => {
                        if (onRequestClose) onRequestClose();
                     }}
                  />
                  <div className="modal-content">
                     <>{children}</>
                  </div>
               </div>
            </ModalContainerStyle>
         )}
      </>,
      document.querySelector('body'),
   );
};

Modal.Body = function ModalBody(props): JSX.Element {
   const { children, show, name, onHide, ...rest } = props;

   return (
      <>
         <ModalStyle {...rest}>{children}</ModalStyle>
      </>
   );
};
